@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF    
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: addkey.pl,v 2.3.2.4 1998/11/25 10:33:58 roman Exp $
+# $Id: addkey.pl,v 2.5 1999/01/11 09:08:27 roman Exp $
 #
 #	$RCSfile: addkey.pl,v $
-#	$Revision: 2.3.2.4 $
+#	$Revision: 2.5 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:33:58 $
+#	$Date: 1999/01/11 09:08:27 $
 
 require "dpr.pl";
 
@@ -187,7 +187,7 @@ sub delkey {
     if ($value=~ s/^$OVERFLOWPREFIXREGULAR//o) {
 	my($overflowname) = $db[1] . $OVERFLOWEXTENSION . $value;
 	if (open(OVERFLOWDEL, "+<".$overflowname)) {
-	    
+	    my($start) = time();
 	    if ((@values=grep(!$mark{$_}, split(/\,/, <OVERFLOWDEL>)))) {
 		
 		seek(OVERFLOWDEL, 0, 0);
@@ -200,6 +200,10 @@ sub delkey {
 		delete $db{$key};
 		close(OVERFLOWDEL);
 		unlink($overflowname);
+		my($elapsed) = time() - $start;
+		my($msg) = "Overflow file $overflowname processed for $elapsed seconds";
+		&syslog("AUDITLOG", $msg) if ($elapsed > 5);
+
 	    }
 	    return;
 	}
