@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: dbadd.pl,v 2.6.2.7 1998/11/25 10:59:00 roman Exp $
+# $Id: dbadd.pl,v 2.13 1999/06/03 12:10:29 rowandb Exp $
 #
 #	$RCSfile: dbadd.pl,v $
-#	$Revision: 2.6.2.7 $
-#	$Author: roman $
-#	$Date: 1998/11/25 10:59:00 $
+#	$Revision: 2.13 $
+#	$Author: rowandb $
+#	$Date: 1999/06/03 12:10:29 $
 
 require "dbopen.pl";
 require "dbclose.pl";
@@ -62,7 +62,8 @@ sub finalchecksandupdate {
     local(@mtdb, %mtdb);
     local(@andb, %andb);
     
-#    &dpr("autonichandles: " . join("*", @autonichandles) . "\n");
+    &dpr("autonichandles: " . join("*", @autonichandles) . "\n") 
+	if (@autonichandles);
     
     if ($options & $DELETEOPTION) {
 	
@@ -118,7 +119,8 @@ sub finalchecksandupdate {
 		# loop through all object types and check if there are object 
 		# of that type pointing to the object being deleted
 
-#		&dpr("=========pointsto: $pointsto==========\n");
+		&dpr("=========pointsto: $pointsto==========\n");
+
 #		my(%referencefound);
 
 		@keys = ();
@@ -136,7 +138,7 @@ sub finalchecksandupdate {
 					    $OBJPOINTSTONICMTATTR{$pointsto})));
 		    }
 		    if ($attr !~ /^\s*$/) {
-#		        &dpr("\$attr = $attr\n");
+		        &dpr("\$attr = $attr\n");
 			@keys = &makekeys($entry{$type}, $attr, *longkeys);
 			@keys = @longkeys if (@longkeys);
 			push(@keys, &makekeys($entry{"nh"}, $attr, *longkeys)) 
@@ -227,12 +229,19 @@ sub finalchecksandupdate {
 			$messg .= (($nor > 1) ? "s\n" : "\n");
 		    }
 		}
-		&adderror(*entry, $messg);
+	        if ($options & $OVERRIDEINTEGRITY){   
+		    &addwarning(*entry, $messg);
+		}
+	 	else {   
+		    &adderror(*entry, $messg);    
+		}
 	    }
 	} 
 	# the actual delete
 	$returncode = &dbdel(*db, *entry, $type, $options, @entrymatch) 
-	    if ($returncode == $O_OK);
+	    if ($returncode == $O_OK
+		|| ($returncode == $E_STILLREFERENCED 
+		    && $options & $OVERRIDEINTEGRITY));
 
 	#closing databases
 	&dbclclose() if ($CLASSLESSDBS{$type});
@@ -288,34 +297,63 @@ sub finalchecksandupdate {
 	
 	# this one is for person objects without a NIC handle
 	if (($type eq "pn") && (!@result) && ($entry{"nh"})) {
-#	    &dpr("doing check for persons without nic handles\n");
+	    &dpr("doing check for persons without nic handles\n");
 	    my($oldvalue)          = delete($entry{"nh"});
 	    local(@otheruniquekey) = (&enukey(*entry, $type));
 	    my(@newresult)         = &dbmatch(*db, *otheruniquekey, "", 
 					      $INTERSECTIONOPTION);
 	    if (@newresult) {
+		&dpr("\@newresult = (", join(", ", @newresult), ")\n");
                 my($offset);
                 foreach $offset (@newresult) {
+		    &dpr("For \$offset=$offset:\n");
 		    &enread($db, *oldobject, $offset);
-		    next if (!&encmp(*entry, *oldobject));
+		    &dpr("\%oldobject = ", join("*", %oldobject), "\n");
+		    next if (!&encmp(*entry, *oldobject, "ch", 1));
+		    &dpr("Compared equal\n");
 		    $done = $offset;
 		    @result = ($done);
 		    last;
                 }
                 %oldobject = () if (!@result);
+		&dpr("\%oldobject = ", join("*", %oldobject), "\n");
 	    }
 	    $entry{"nh"} = $oldvalue;
 	}
 	
+	# this one is for changing person's name only
+#	if (($type eq "pn") && (!@result) && ($entry{"nh"})) {
+#	    &dpr("doing check for changing person's names\n");
+#	    local(@longkeys) = ();
+#	    local(@keys)   = &makekeys($entry{"nh"}, "", *longkeys);
+#	    &dpr("\@keys = ", join("*", @keys), "\n");
+#	    my(@newresult) = &dbmatch(*db, *keys, "", 0);
+#	    if (@newresult) {
+#		&dpr("\@newresult = (", join(", ", @newresult), ")\n");
+#                my($offset);
+#		my(@exclude) = ('pn');
+#                foreach $offset (@newresult) {
+#		    &enread($db, *oldobject, $offset);
+#		    next if (!&encmp(*entry, *oldobject, @exclude));
+#		    $done = $offset;
+#		    @result = ($done);
+#		    last;
+#                }
+#                %oldobject = () if (!@result);
+#		&dpr("\%oldobject = ", join("*", %oldobject), "\n");
+#		&dpr("\%entry = ", join("*", %entry), "\n");
+#	    }
+#	}
+	
 	# check if we are doing a modification
 	if (@result) {
 	    if (scalar(@result)>1) {
-#		&dpr("multiple match - $entry{$type}\n");
+		&dpr("multiple match - $entry{$type}\n");
 	        $returncode = $E_MULT_MATCH;
 	    }
 	    else {
 	        &enread($db, *oldobject, $result[0]) if (!%oldobject);
-#	        &dpr("modification match - $oldobject{$type}\n");
+	        &dpr("modification match - $oldobject{$type}\n");
                 $options |= $MODIFYOPTION;
                 $returncode = $E_NOOP if (&encmp(*entry, *oldobject));
                 $returncode = $E_NOTNEW 
@@ -394,7 +432,7 @@ sub finalchecksandupdate {
 		($options & $NEWOPTION) && 
 		($entry{"nh"})) {
 
-#		&dpr("doing handle already in use check\n");
+		&dpr("doing handle already in use check\n");
 		local(@longkeys) = ();
 		local(@keys) = &makekeys($entry{"nh"}, "", *longkeys);
 		if ((&dbmatch(*db, *keys, "", 0)) ||
@@ -411,15 +449,15 @@ sub finalchecksandupdate {
 	    if (($options & $NEWOPTION) && 
 		($type eq 'pn')         && 
 		$DUPLICATEPERSONCHECK) {
-#		&dpr("****************************\n");
-#		&dpr("doing duplicate person check\n");
-#		&dpr("****************************\n");
+		&dpr("****************************\n");
+		&dpr("doing duplicate person check\n");
+		&dpr("****************************\n");
 		local(@longkeys);
 		local(@keys) = &makekeys($entry{$type}, "", *longkeys);
 		@keys = @longkeys if (@longkeys);
 		my(@results) = &dbmatch(*db, *keys, "", 0);
 
-#		&dpr("\%entry = " . join("*", %entry) . "\n");
+		&dpr("\%entry = " . join("*", %entry) . "\n");
 
 		if (@results) {
 		    my($messg) = "Other person object(s) with the " .
@@ -428,7 +466,7 @@ sub finalchecksandupdate {
 			local(%otherobj);
 			&enread($db, *otherobj, $_);
 			next if (&encmp(*entry, *otherobj));
-#			&dpr("\%other = " . join("*", %otherobj) . "\n");
+			&dpr("\%other = " . join("*", %otherobj) . "\n");
 			$messg .= ("\n" . $otherobj{'nh'}) if ($otherobj{'nh'});
 			if (&cmpContactData(\%entry, \%otherobj)) {
 			    if ($DUPLICATEPERSONCHECK =~ /^strict$/i) {
@@ -492,10 +530,18 @@ sub finalchecksandupdate {
 		    $ExistMntner{$CurMnt{'mt'}} = 1;
 		}
 	    }
+
+            &dbclose(*mtdb) if ($type ne 'mt');
+
 	    if (@notfoundmnt) {
-                &adderror(*entry,
-			  "Unknown maintainer(s) @notfoundmnt referenced");
-                $returncode = $E_GENERAL;
+		my($messg) = "Unknown maintainer(s) @notfoundmnt referenced";
+		if ($options & $OVERRIDEINTEGRITY) {
+		    &addwarning(*entry, $messg);
+		}
+		else {
+		    &adderror(*entry, $messg);
+		    $returncode = $E_GENERAL;
+		}
 	    }
 
 	    foreach $nic (@nics) {
@@ -525,17 +571,29 @@ sub finalchecksandupdate {
 		}
 	    }
 	    if (@notfoundnic) {
-		&adderror(*entry, 
-			  "Unknown nic handle(s) @notfoundnic referenced");
-		$returncode = $E_GENERAL;
+		my($messg) = 
+		    "Unknown nic handle(s) @notfoundnic referenced";
+		if ($options & $OVERRIDEINTEGRITY) {
+		    &addwarning(*entry, $messg);
+		}
+		else {
+		    &adderror(*entry, $messg);
+		    $returncode = $E_GENERAL;
+		}
 	    }
 	    if ($type eq 'rt') {
 		local(@longkeys);
 		local(@keys)   = &makekeys($AS, " ", *longkeys);
 		my(@result) = &dbmatch(*andb, *keys, " ", 0);
 		if (!@result) {
-		    &adderror(*entry, "Unknown AS $AS referenced");
-		    $returncode = $E_GENERAL;
+		    my($messg) = "Unknown AS $AS referenced";
+		    if ($options & $OVERRIDEINTEGRITY) {
+			&addwarning(*entry, $messg);
+		    }
+		    else {
+			&adderror(*entry, "Unknown AS $AS referenced");
+			$returncode = $E_GENERAL;
+		    }
 		}
 	    }
 	}
@@ -618,28 +676,24 @@ sub dbadd {
 #	&dpr("adding normal & unique keys\n\t$_\n");
 	&addkey(*db, $_, $offset);
 #	&dpr("\$db{$_} = $db{$_}\n");
-#	print STDERR "\$db{$_} = $db{$_}\n";
     }
     
     foreach (@other) {
 #	&dpr("adding other keys\n\t$_\n");
 	&addkey(*db, $_, $offset);
 #	&dpr("\$db{$_} = $db{$_}\n");
-#	print STDERR "\$db{$_} = $db{$_}\n";
     }
     
     foreach (@pointsto) {
 #	&dpr("adding pointsto keys\n\t$_\n");
 	&addkey(*db, $_, $offset);
 #	&dpr("\$db{$_} = $db{$_}\n");
-#	print STDERR "\$db{$_} = $db{$_}\n";
     }
 
     foreach (@otherpointsto) {
 #	&dpr("adding otherpointsto keys\n\t$_\n");
 	&addkey(*db, $_, $offset);
 #	&dpr("\$db{$_} = $db{$_}\n");
-#	print STDERR "\$db{$_} = $db{$_}\n";
     }
     
     # No need to modify the classless index if this is a
