@@ -20,36 +20,38 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: dbclose.pl,v 2.3.2.6 1998/11/25 00:31:36 roman Exp $
+# $Id: dbclose.pl,v 2.5 1999/01/11 09:08:29 roman Exp $
 #
 #	$RCSfile: dbclose.pl,v $
-#	$Revision: 2.3.2.6 $
+#	$Revision: 2.5 $
 #	$Author: roman $
-#	$Date: 1998/11/25 00:31:36 $
+#	$Date: 1999/01/11 09:08:29 $
 
 sub dbclose {
     local(*db) = @_;
     my($name) = $db[1];
 
     if ($db[0] == 1) {
-	&dpr("closing database $name\n");
-	$::opened_databases{$name}{'open_count'}--;
-	if ( $::opened_databases{$name}{'open_count'} == 0 ) {
+#	&dpr("closing database $name\n");
+	# $::opened_databases{$name}{'open_count'}--;
+	# if ( $::opened_databases{$name}{'open_count'} == 0 ) {
 	    untie %db;
 	    &fatalerror("in dbclose: cannot close $name -  code: $!") 
 		if ( ! close($db) );
-#	    $db[0] = 0;
-#	    $db[1] = "";
-	    undef @db;
-	    undef %db;
-	    delete $::opened_databases{$name}{'open_count'};
-	    delete $::opened_databases{$name}{'handle'};
-	    delete $::opened_databases{$name}{'array'};
-	    delete $::opened_databases{$name}{'tied_hash'};
-	    delete $::opened_databases{$name}{'status'};
-	    delete $::opened_databases{$name};
-	    &dpr("database $name closed\n");
-	}
+
+	    $db[0] = 0;
+	    $db[1] = "";
+
+	    # undef @db;
+	    # undef %db;
+	    # delete $::opened_databases{$name}{'open_count'};
+	    # delete $::opened_databases{$name}{'handle'};
+	    # delete $::opened_databases{$name}{'array'};
+	    # delete $::opened_databases{$name}{'tied_hash'};
+#	    delete $::opened_databases{$name}{'status'};
+#	    delete $::opened_databases{$name};
+#	    &dpr("database $name closed\n");
+	# }
     }
 }
 
