@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: dbmatch.pl,v 2.3.2.2 1998/11/06 15:06:03 roman Exp $
+# $Id: dbmatch.pl,v 2.6 1999/06/03 12:10:32 rowandb Exp $
 #
 #	$RCSfile: dbmatch.pl,v $
-#	$Revision: 2.3.2.2 $
-#	$Author: roman $
-#	$Date: 1998/11/06 15:06:03 $
+#	$Revision: 2.6 $
+#	$Author: rowandb $
+#	$Date: 1999/06/03 12:10:32 $
 #
 #	looks up the offsets in the dbm file for all keys
 #       and will return an array with the intersection of all
@@ -41,8 +41,8 @@ require "dpr.pl";
 
 sub dbmatch {
     local(*db, *allkeys, $types, $options) = @_;
-    &dpr("\@allkeys = (", join(" ", @allkeys), ") \$types = $types\n");
 
+    &dpr("\@allkeys = (", join(" ", @allkeys), ") \$types = $types\n");
 
     local(%tmp)=();
     local(%nonsplitkeys)=();
@@ -72,7 +72,7 @@ sub dbmatch {
 
     foreach $key (@keys) {
 
-	&dpr("\$key = $key, \$db{\$key} = $db{$key}, \$options = $options\n");
+#	&dpr("\$key = $key, \$db{\$key} = $db{$key}, \$options = $options\n");
         
        if ($key=~ /^$VALIDPREFIXKEY$/o) {
           
