@@ -20,15 +20,15 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: dbopen.pl,v 2.10.2.6 1998/11/25 10:34:00 roman Exp $
+# $Id: dbopen.pl,v 2.12 1999/01/11 09:08:30 roman Exp $
 #
 # ***NOTE***: flock doesn't work on NFS mounted file systems!!!
 #             and thus locking doesn't work properly on NFS file systems
 #
 #	$RCSfile: dbopen.pl,v $
-#	$Revision: 2.10.2.6 $
+#	$Revision: 2.12 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:34:00 $
+#	$Date: 1999/01/11 09:08:30 $
 #
 #
 # arguments:
@@ -52,6 +52,8 @@
 require "defines.pl";
 require "dpr.pl";
 
+# use Hash2Hash;
+
 # return name of db file given text-file name
 sub dbfilename { return $_[0].'.db' }
 
@@ -75,40 +77,64 @@ sub dbname {
 sub dbopen {
     local(*database, *entry, $write, $name) = @_;
 
-    &dpr("called with \$database = $database, \n\t\@database = " . 
-	 join("*", @database) . "\n\t\$write = $write, \$name = $name\n" .
-	 "\t\%entry = " . join("*", %entry) . "\n");
+#    &dpr("called with \$database = $database, \n\t\@database = " . 
+#	 join("*", @database) . "\n\t\$write = $write, \$name = $name\n" .
+#	 "\t\%entry = " . join("*", %entry) . "\n");
 
     $name = &dbname(*entry) if ($name=~ /^\s*$/);
     my($dbfilename) = dbfilename($name);
-    my($open_status);
-    my($lock_mode);
-    my($lock_pid);
 
-    &dpr("name: $name\n") if ($name);
+#    my($open_status);
+#    my($lock_mode);
+#    my($lock_pid);
 
-    if ($open_status = $::opened_databases{$name}{'status'}) {
-	$open_status =~ /^(\w+)\:(\w+)$/;
-	$lock_mode = $1;
-	$lock_pid = $2;
-    }
+#    &dpr("name: $name\n") if ($name);
+
+#    if ($open_status = $::opened_databases{$name}{'status'}) {
+#	$open_status =~ /^(\w+)\:(\w+)$/;
+#	$lock_mode = $1;
+#	$lock_pid = $2;
+#    }
     
     if ($write) {
 
-	if ($open_status && ($lock_pid == $$)) {
-	    &dpr("database file $name already opened - lock: $lock_mode, " .
-		 "PID: $lock_pid\n");
-	    if ($lock_mode == $LOCK_SH) {
-		&dpr("Exclusive lock requested - will probably block\n");
-	    }
-	    else {
-		$::opened_databases{$name}{'open_count'}++;
-		$database = ${$::opened_databases{$name}{'handle'}};
-		@database = @{$::opened_databases{$name}{'array'}};
-		%database = %{$::opened_databases{$name}{'tied_hash'}};
-		return 1;
-	    }
-	}
+#	if ($open_status && ($lock_pid == $$)) {
+#	    &dpr("database file $name already opened - lock: $lock_mode, " .
+#		 "PID: $lock_pid\n");
+#	    &syslog("AUDITLOG", 
+#		    "database file $name already opened - lock: $lock_mode, " .
+#		    "PID: $lock_pid");
+#	    if ($db[0] == 1) {
+#		# we are trying to open the same handle
+#		if ($lock_mode == $LOCK_SH) {
+#		    &dpr("Exclusive lock requested - try to acquire\n");
+#		    flock($database, $LOCK_UN);
+#		    unless (flock($database, $LOCK_EX | $LOCK_NB)) {
+#			my $msg = 
+#			    "CONTENTION - cannot get exclusive " .
+#			    "lock on $name!\n" .
+#			    "Waiting for write lock ($!)...";
+#			&dpr($msg . "\n");
+#			&syslog("AUDITLOG", $msg);
+#			flock($database, $LOCK_EX) || die("flock: $!");
+#		    }
+#		}
+#		else {
+#		    # $::opened_databases{$name}{'open_count'}++;
+#		    # $database = ${$::opened_databases{$name}{'handle'}};
+#		    # @database = @{$::opened_databases{$name}{'array'}};
+#		    # tie(%database, 'Hash2Hash', 
+#		    # $::opened_databases{$name}{'tied_hash'});
+#		    # %database = %{$::opened_databases{$name}{'tied_hash'}};
+#		}
+#		return 1;
+#	    }
+#	    else {
+#		# we are trying to open another handle
+#		# just go ahead and open the same file again
+#		# what happens if we have read lock on other handle ?!?
+#	    }
+#	}
 		
 	# If we want to open the dbfile for writing, make sure that
 	# cleandb is not using the database. If it is there will be a
@@ -146,44 +172,70 @@ sub dbopen {
 	    }
 	}
 	unless (flock($database, $LOCK_EX | $LOCK_NB)) {
-	    &dpr("CONTENTION - cannot get exclusive lock on $name!\n" .
-		 "Waiting for write lock ($!)...\n");
+	    my $start = time();
+	    my $msg = 
+		"CONTENTION - cannot get exclusive lock on $name!\n" .
+		"Waiting for write lock ($$: $!)...";
+	    &dpr($msg . "\n");
+	    &syslog("AUDITLOG", $msg);
+
 	    flock($database, $LOCK_EX) || die("flock: $!");
+
+	    my $elapsed = time() - $start;
+	    $msg = "Lock acquired - $$ waited for $elapsed seconds";
+	    &dpr($msg . "\n");
+	    &syslog("AUDITLOG", $msg);
 	}
 	$DB_HASH->{cachesize} = $DBCACHESIZE;
 	tie (%database, DB_File, $dbfilename, O_CREAT|O_RDWR, 0644, $DB_HASH)
 	    || &fatalerror("Couldn\'t open dbm file($!): $dbfilename"); 
 #	print STDERR "database file $name opened, index tied to $dbfilename\n";
-	$::opened_databases{$name}{'status'}    = "$LOCK_EX:$$";
-        $::opened_databases{$name}{'open_count'}++;
+#	$::opened_databases{$name}{'status'}    = "$LOCK_EX:$$";
+#        $::opened_databases{$name}{'open_count'}++;
     }
     else { 
         # open readonly
-	if ($open_status && ($lock_pid == $$)) {    # database already open
-	    &dpr("database file $name already opened - lock: $lock_mode, " .
-		"PID: $lock_pid\n");
-	    $::opened_databases{$name}{'open_count'}++;
-	    $database = ${$::opened_databases{$name}{'handle'}};
-	    @database = @{$::opened_databases{$name}{'array'}};
-	    %database = %{$::opened_databases{$name}{'tied_hash'}};
-	    return 1;
-	}
+#	if ($open_status && ($lock_pid == $$)) {    
+#	    my $msg = 
+#		"database file $name already opened - lock: " . 
+#		    "$lock_mode, PID: $lock_pid";
+#	    &dpr($msg . "\n");
+#	    &syslog("AUDITLOG", $msg);
+#	    if ($db[0] == 1) {
+#		# we are trying to open the same handle
+#		return 1;
+#	    }
+#	    else {
+#		# $::opened_databases{$name}{'open_count'}++;
+#		# $database = ${$::opened_databases{$name}{'handle'}};
+#		# @database = @{$::opened_databases{$name}{'array'}};
+#		# tie(%database, 'Hash2Hash',
+#		# $::opened_databases{$name}{'tied_hash'});
+#		# %database = %{$::opened_databases{$name}{'tied_hash'}};
+#		# return 1;
+#	    }
+#	}
+
 	return 0 if (!open($database, "<$name"));
-	unless (flock($database, $LOCK_SH | $LOCK_NB)) {
-	    &dpr("CONTENTION - can't read during write update on $name!\n" .
-		 "Waiting for read lock ($!)...\n");
-	    flock($database, $LOCK_SH) || die("flock: $!");
-	}
+
+#	unless (flock($database, $LOCK_SH | $LOCK_NB)) {
+#	    &dpr("CONTENTION - can't read during write update on $name!\n" .
+#		 "Waiting for read lock ($!)...\n");
+#	    flock($database, $LOCK_SH) || die("flock: $!");
+#	}
+
 	tie (%database, DB_File, $dbfilename, O_RDONLY) || return 0;
-#	print STDERR "database file $name opened, index tied to $dbfilename\n";
-	$::opened_databases{$name}{'status'} = "$LOCK_SH:$$";
-        $::opened_databases{$name}{'open_count'}++;
+
+#	$::opened_databases{$name}{'status'} = "$LOCK_SH:$$";
+#        $::opened_databases{$name}{'open_count'}++;
     }
     local($oldhandle) = select($database); $|=1; select($oldhandle);
-    @database = (1, $name, ($write) ? $LOCK_EX : $LOCK_SH);
-    $::opened_databases{$name}{'handle'}    = \$database;
-    $::opened_databases{$name}{'array'}     = \@database;
-    $::opened_databases{$name}{'tied_hash'} = \%database;
+    @database = (1, $name);
+
+    # $::opened_databases{$name}{'handle'}    = \$database;
+    # $::opened_databases{$name}{'array'}     = \@database;
+    # $::opened_databases{$name}{'tied_hash'} = \%database;
+
     return 1;
 }
 
