@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: defines.pl,v 2.4.2.2 1998/11/06 15:06:07 roman Exp $
+# $Id: defines.pl,v 2.9 1999/02/02 14:42:01 marek Exp $
 #
 #	$RCSfile: defines.pl,v $
-#	$Revision: 2.4.2.2 $
-#	$Author: roman $
-#	$Date: 1998/11/06 15:06:07 $
+#	$Revision: 2.9 $
+#	$Author: marek $
+#	$Date: 1999/02/02 14:42:01 $
 
 $OK		=	1;
 $NOK		=	0;
@@ -54,18 +54,22 @@ $E_NOAUTOUPDATE  =     12;
 $E_NOTNEW        =     13;
 $E_STILLREFERENCED =   14;
 
-$MESSAGE[$E_EXIST]	= "entry already exists";
-$MESSAGE[$E_NOT_FOUND]	= "entry not found";
-$MESSAGE[$E_MULT_MATCH]	= "more than one match";
-$MESSAGE[$E_MISMATCH]	= "mismatch between update and original";
-$MESSAGE[$E_NOOP]	= "update results in NOOP";
-$MESSAGE[$E_OLDER]	= "update is older than original";
-$MESSAGE[$E_AUTHFAIL]   = "authorisation failed, request forwarded to maintainer";
-$MESSAGE[$E_HIER_AUTHFAIL] = "hierarchical authorisation failed, request forwarded to maintainer\nof object directly above the to be updated object in the hierarchy";
-$MESSAGE[$E_NOAUTOUPDATE] = "object cannot be updated\/deleted automatically\nthe to be updated\/deleted object doesn\'t contain\na ".$ATTL{"mb"}." line.\nplease contact \<$HUMAILBOX\> for updating this object";
-$MESSAGE[$E_GENERAL]    = "";
-$MESSAGE[$E_NOTNEW]     = "object already exists";
-$MESSAGE[$E_STILLREFERENCED] = "cannot delete object that is still referenced\nby other objects in the database";
+# Error messages.
+#
+# Attention: the contents of these strings will be eval'd,
+# 	hence nested quotes
+$MESSAGE[$E_EXIST]	= '"entry already exists"';
+$MESSAGE[$E_NOT_FOUND]	= '"entry not found"';
+$MESSAGE[$E_MULT_MATCH]	= '"more than one match"';
+$MESSAGE[$E_MISMATCH]	= '"mismatch between update and original"';
+$MESSAGE[$E_NOOP]	= '"update results in NOOP"';
+$MESSAGE[$E_OLDER]	= '"update is older than original"';
+$MESSAGE[$E_AUTHFAIL]   = '"authorisation failed, request forwarded to maintainer"';
+$MESSAGE[$E_HIER_AUTHFAIL] = '"hierarchical authorisation failed, request forwarded to maintainer\nof object directly above the to be updated object in the hierarchy"';
+$MESSAGE[$E_NOAUTOUPDATE] = '"the object in the database does not contain\na mandatory ".$ATTL{"mb"}." attribute,\ntherefore user updates of this object are disabled\nplease contact \<$HUMAILBOX\> for updating this object"';
+$MESSAGE[$E_GENERAL]    = '""';
+$MESSAGE[$E_NOTNEW]     = '"object already exists"';
+$MESSAGE[$E_STILLREFERENCED] = '"cannot delete object that is still referenced\nby other objects in the database"';
 
 #
 # Return codes for syntax checking the objects
@@ -87,9 +91,9 @@ $O_NOTFOUND=28;
 $O_COULDNOTOPEN=29; 
 
 
-$MESSAGE[$O_OK]		=	"object OK";
-$MESSAGE[$O_ERROR]	=	"object has errors";
-$MESSAGE[$O_WARNING]	=	"object has warnings";
+$MESSAGE[$O_OK]		=	'"object OK"';
+$MESSAGE[$O_ERROR]	=	'"object has errors"';
+$MESSAGE[$O_WARNING]	=	'"object has warnings"';
 
 # Return codes for authorisation
 
@@ -147,6 +151,7 @@ $NOOPOPTION=64;
 $FAILEDOPTION=128;
 $BACKWARDCOMPATIBILITYOPTION=256;
 $ASSIGNEDNICOPTION=512;
+$OVERRIDEINTEGRITY=1024;
 
 #
 # donetdbm (binary) options
