@@ -21,47 +21,61 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: encmp.pl,v 2.4.2.1 1998/11/06 15:06:08 roman Exp $
+# $Id: encmp.pl,v 2.8 1999/06/03 12:10:32 rowandb Exp $
 #
 #	$RCSfile: encmp.pl,v $
-#	$Revision: 2.4.2.1 $
-#	$Author: roman $
-#	$Date: 1998/11/06 15:06:08 $
+#	$Revision: 2.8 $
+#	$Author: rowandb $
+#	$Date: 1999/06/03 12:10:32 $
 #
 #	This routine takes two objects and compares them case insensitive
 #	Returns 1 if objects are equal, else returns 0;
 #
 #       Arguments:
 #	*this, *that		two pointers to assoc arrays
+#       @what                   list of attributes to exclude from comparison
+
 
 sub encmp {
 
-    local(*this, *that)=@_;
+    local(*this, *that, $what, $ignorewhitespace)=@_;
     
     local($a,$b);
-
+    local(@syntacticsugar)=();
     local($atype)=&entype(%this);
 
-    #
+    my @what = split(/ /, $what);
+
     # check if types are different
-    
+
+#    &dpr("First object =", join("*", %this), "\n");
+#    &dpr("Second object =", join("*", %that), "\n");
+    &dpr("\@what=", join(" ", @what), "\n");
+    &dpr("Ignoring whitespace...\n") if ($ignorewhitespace);
+
     return 0 if ($atype ne &entype(%that));
 
-    #
     # check every attribute line by line...
-    #
     # but do the difficult cases last.
-    
-    local(@syntacticsugar)=();
-    
-    foreach (split(/\s+/, $OBJATSQ{$atype})) {
+
+    my(@compareattrs) = split(/\s+/, $OBJATSQ{$atype});
+    my(%excludeattrs) = undef;
+    grep($excludeattrs{$_}++, @what); 
+
+    foreach (@compareattrs) {
         
         $a=$this{$_};
 	$b=$that{$_};
         
-	next if ($_ eq "ch");
-        # print STDERR "-$a-$b-";
-        
+	next if ($excludeattrs{$_});
+
+	&dpr("Comparing $_: *$a* *$b*\n");
+
+	if ($ignorewhitespace) {
+	    $a =~ s/\s+/ /g;
+	    $b =~ s/\s+/ /g;
+	}        
+
 	# we need to do quite a bit of work for comparing attributes
 	# that might have syntactic sugar so let's store these attributes 
 	# and process them last!
