@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: enkeys.pl,v 2.2.2.4 1998/11/25 11:06:33 roman Exp $
+# $Id: enkeys.pl,v 2.4 1999/01/11 09:08:33 roman Exp $
 #
 #	$RCSfile: enkeys.pl,v $
-#	$Revision: 2.2.2.4 $
+#	$Revision: 2.4 $
 #	$Author: roman $
-#	$Date: 1998/11/25 11:06:33 $
+#	$Date: 1999/01/11 09:08:33 $
 #
 
 #
@@ -88,8 +88,8 @@ require "dpr.pl";
 sub makekeys {
 
     local($searchstring, $tags, *others)=@_;
-#    &dpr("\$searchstring = $searchstring, \$tags = $tags, ",
-#	 "\@others = ", join(" ", @others), "\n");
+    &dpr("\$searchstring = $searchstring, \$tags = $tags, ",
+	 "\@others = ", join(" ", @others), "\n");
 
     # we make a dummy object for finding the keys
        
@@ -131,12 +131,12 @@ sub makekeys {
 
     &enkeys(*dummyentry, $tags, *keys, *others, *pointsto, *otherpointsto, *classless, $classless);
     
-#    &dpr("enkeys returned:\n");
-#    &dpr("\t\@keys = (", join("*", @keys), ")\n") if (@keys);
-#    &dpr("\t\@others = (", join("*", @others), ")\n") if (@others);
-#    &dpr("\t\@pointsto = (", join("*", @pointsto), ")\n") if (@pointsto);
-#    &dpr("\t\@otherpointsto = (", join("*", @otherpointsto), ")\n") if (@otherpointsto);
-#    &dpr("\t\@classless = (", join("*", @classless), ")\n") if (@classless);
+    &dpr("enkeys returned:\n");
+    &dpr("\t\@keys = (", join("*", @keys), ")\n") if (@keys);
+    &dpr("\t\@others = (", join("*", @others), ")\n") if (@others);
+    &dpr("\t\@pointsto = (", join("*", @pointsto), ")\n") if (@pointsto);
+    &dpr("\t\@otherpointsto = (", join("*", @otherpointsto), ")\n") if (@otherpointsto);
+    &dpr("\t\@classless = (", join("*", @classless), ")\n") if (@classless);
    
     if ($tags!~ /^\s*$/) {
        
