@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: enparse.pl,v 2.3.2.5 1998/11/25 10:59:02 roman Exp $
+# $Id: enparse.pl,v 2.6 1999/05/17 10:05:48 engin Exp $
 #
 #	$RCSfile: enparse.pl,v $
-#	$Revision: 2.3.2.5 $
-#	$Author: roman $
-#	$Date: 1998/11/25 10:59:02 $
+#	$Revision: 2.6 $
+#	$Author: engin $
+#	$Date: 1999/05/17 10:05:48 $
 #
 #	ARGUMENTS:	filehandle to read from
 #	RETURNS:	INTEGER object_status
@@ -55,6 +55,7 @@ require "defines.pl";
 require "adderror.pl";
 require "dpr.pl";
 require "pgp.pl";
+require "i6.pl";
 
 sub readsomething {
     local($file)=@_;
@@ -67,6 +68,8 @@ sub readsomething {
     
     local($newtag);
 
+    &dpr("\n");
+
     while (<$file>) {
         
         #
@@ -248,7 +251,7 @@ sub checkobject	{
     local(%usefield) = ();
     local($i);
 
-#    &dpr("called with \%object = " . join("*", %object) . "\$type = $type\n");
+    &dpr("called with \%object = " . join("*", %object) . "\$type = $type\n");
     
     foreach $i ((split(/\s+/, $OBJATSQ{$type}),"ud","uo","uw","ue")) {
 	$knownfield{$i}=1;
@@ -293,6 +296,7 @@ sub checkobject	{
 			  "attribute \"$i\" unknown in $ATTL{$type} object");
 	    }
 	    $rtcode = $O_ERROR;
+	    next;
 	}
 
 	undef $mandfield{$i} unless $object{$i} eq "";
@@ -366,7 +370,7 @@ sub enparse {
 
     ($stat, %entry)=&readsomething($file);
 
-    # &dpr("\%entry = " . join("*", %entry) . "\n");
+    &dpr("\%entry = " . join("*", %entry) . "\n");
     
     return $EOF if ($stat==$EOF);
 
@@ -387,7 +391,7 @@ sub enparse {
     
     if ((!defined($entry{"ud"})) && ($rtcode!=$O_ERROR)) {
        
-#       &dpr("checking object format\n");
+       &dpr("checking object format\n");
        
        local($code)=&checkobject(*entry, $type);
        
@@ -399,7 +403,7 @@ sub enparse {
        
        if ($rtcode!=$O_ERROR) {
        
-#          &dpr("checking object syntax\n");
+          &dpr("checking object syntax\n");
 	  
 	  $code=&checksyntax(*entry);
 	  
@@ -420,9 +424,16 @@ sub enparse {
 	   and $rtcode = $O_ERROR;
     }
 
+    if ($type eq "i6" && $rtcode != $O_ERROR) {
+       print STDERR "enparse - adding the generated fields in an inet6num object \n" if ($opt_V);
+
+       geni6st(*entry, $type) == $O_ERROR
+	   and $rtcode = $O_ERROR;
+    }
+
     # print STDERR %entry, "\n";
-#    &dpr("Exiting enparse.\nExit code: $rtcode\nType: $type\nEntry:",
-#	 %entry,"\n");
+    &dpr("Exiting enparse.\nExit code: $rtcode\nType: $type\nEntry:",
+	 %entry,"\n");
     
     return ($rtcode, $type, %entry);
     
