@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: enwrite.pl,v 2.4.2.3 1998/11/25 10:34:02 roman Exp $
+# $Id: enwrite.pl,v 2.5 1998/12/09 14:39:16 roman Exp $
 #
 #	$RCSfile: enwrite.pl,v $
-#	$Revision: 2.4.2.3 $
+#	$Revision: 2.5 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:34:02 $
+#	$Date: 1998/12/09 14:39:16 $
 #
 #	This routine writes a RIPE database entry to standard output
 #	in long or short form.
@@ -65,7 +65,7 @@ sub enwrite {
 	return 0 if (!$long);
 	return 0 if (!$witherrors);
 
-        &fatalerror("in enwrite: cannot write. code: $!") if ( ! print $output "\n");
+        &fatalerror("enwrite(1): cannot write. code: $!") if ( ! print $output "\n");
 
     
         $offset=tell($output);
@@ -83,13 +83,13 @@ sub enwrite {
 	          $key="*".$key;
 	       }
 	       
-               &fatalerror("in enwrite: cannot write. code: $!") if ( ! printf $output "%-15s %s\n", $key.":", $val );
+               &fatalerror("enwrite(2): cannot write. code: $!") if ( ! printf $output "%-15s %s\n", $key.":", $val );
 	       
 	    }
 	
 	}
 	
-        &fatalerror("in enwrite: cannot write. code: $!") if ( ! printf $output "%-15s %s\n", $ATTL{"ue"}.":", "Unknown object type" );
+        &fatalerror("enwrite(3): cannot write. code: $!") if ( ! printf $output "%-15s %s\n", $ATTL{"ue"}.":", "Unknown object type" );
 	
 	return $offset;
     
@@ -97,7 +97,7 @@ sub enwrite {
 
     if ($object{$type}) {
 
-       &fatalerror("in enwrite: cannot write. code: $!") if ( ! print $output "\n"); 
+       &fatalerror("enwrite(4): cannot write. code: $!") if ( ! print $output "\n"); 
     
        $offset=tell($output);
 	    
@@ -144,11 +144,11 @@ sub enwrite {
 
 		    # END HARDCODED
 
-                    &fatalerror("in enwrite: cannot write. code: $!") if ( ! printf $output "%-12s %s\n", $ATTL{$key}.":", $val );
+                    &fatalerror("enwrite(5): cannot write. code: $!") if ( ! printf $output "%-12s %s\n", $ATTL{$key}.":", $val );
 
 		}
 		else {
-                    &fatalerror("in enwrite: cannot write. code: $!") if ( ! print $output "*", $key, ": ", $val, "\n" );
+                    &fatalerror("enwrite(6): cannot write. code: $!") if ( ! print $output "*", $key, ": ", $val, "\n" );
 		}
 	    }
 	}
