@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: hiermnt.pl,v 2.2.2.3 1998/11/25 10:59:03 roman Exp $
+# $Id: hiermnt.pl,v 2.6 1999/05/28 16:19:46 roman Exp $
 #
 #	$RCSfile: hiermnt.pl,v $
-#	$Revision: 2.2.2.3 $
+#	$Revision: 2.6 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:59:03 $
+#	$Date: 1999/05/28 16:19:46 $
 
 # hiermnt.pl - implements the hierarchical authorization methods
 # it works only for creation right now...
@@ -63,6 +63,13 @@ sub HierarchicalAuthorization {
              return &AuthorizeInetnum(*db, $options, $type, *OldObject, *NewObject, $NewObject{$type}, &enukey(*NewObject,$type));
           
           }
+##\begin[1999 02 18]{engin}
+          elsif ($type eq "i6") {
+       
+             return &AuthorizeInetv6num(*db, $options, $type, *OldObject, *NewObject, $NewObject{$type}, &enukey(*NewObject,$type));
+          
+          }
+##\end{engin}
           elsif ($type eq "dn") {
           
              return &AuthorizeDomain(*db, $options, $type, *OldObject, *NewObject, $NewObject{$type});
@@ -109,8 +116,14 @@ sub DoHierarchicalAuthorization {
           
           if ($directabove{"ml"}) {
           
-             $returncode=$E_HIER_AUTHFAIL if (!&Maintainer(*OldObject, *NewObject, $options, $directabove{"ml"}));
-          
+	      if (&Maintainer(*OldObject, *NewObject, 
+			      $options, $directabove{"ml"})) {
+		  &NotifyMaintainers(*OldObject, *NewObject, $directabove{"ml"});
+	      }
+	      else{
+		  $returncode = $E_HIER_AUTHFAIL;
+	      }
+
           }
           
           last;
@@ -258,6 +271,93 @@ sub AuthorizeInetnum {
     
 }
     
+##\begin[1999 02 18]{engin}
+sub AuthorizeInetv6num{
+
+    local(*db, $options, $type, *OldObject, *NewObject, $value, $uniquekey)=@_;
+    
+    local($returncode)=$O_OK;
+    local($code);
+    
+    local(%directabove)=();
+    local(@lessspecifics)=();
+     
+    local($key); 
+     
+    $directabove{$type}=$value;
+    
+#    &dpr("hierarchical inetnum direct above=",$directabove{$type},"\n");
+    
+    local(@keys,@other,@pointsto,@otherspointsto,@classless);
+    
+    &enkeys(*directabove, $KEYS{$type}, *keys, *other, *pointsto, *otherspointsto, *classless, 1);
+    
+#    &dpr("hierarchical inetnum keys=", join(" ", @classless) ,"\n");
+    
+    #
+    # we don't have time for sophisticated routines now
+    # and it looks like brute force might be more efficient anyway
+    # so here we go ...
+    #
+    # first find all less specific objects
+    
+    foreach $key (@classless) {
+    
+       #
+       # we try to find all less specifics to be sure that we find
+       # the right objects in case of non-split databases
+       # no time right now to handle this differently for split and
+       # and non split databases...
+       # note: a parent in a non-split database might be an object
+       # with another type, yes we might call this a bug...
+       
+       push(@lessspecifics, &findlsps(*mspnxl, $key, 1));
+
+    
+    }
+    
+#    &dpr("hierarchical inetnum lessspecifics=", 
+#	 join(" ", @lessspecifics) ,"\n");
+    
+    #
+    # remove doubles (grep perl trick, see camel book)
+    
+    local(%tmp)=();
+    grep($tmp{$_}++, @lessspecifics);
+    @lessspecifics=keys(%tmp);
+    
+#    &dpr("hierarchical inetnum after removing doubles lessspecifics=", 
+#	 join(" ", @lessspecifics) ,"\n");
+    
+    #
+    # find the smallest objects that are bigger then the current object
+    
+    local(@directabove)=();
+
+# now, try to find the smallest one in @lessspecifics:
+    local($size);
+    $size = 0;
+    foreach $key  (@lessspecifics){
+       ($prefixv6,$lengthv6) = split(/\//,$key);
+       if ($lengthv6 > $size){
+          $size = $lengthv6;
+          @directabove = ($key); 
+       }
+    }
+
+    
+    
+    $code=&DoHierarchicalAuthorization(*db, $options, $type, *OldObject, *NewObject, *directabove);
+    
+    # everything is fine if we didn't find any parent object
+    
+    return $O_OK if ($code==$O_NOTFOUND);
+    
+    return $code;
+
+}
+##\end{engin}
+
 sub AuthorizeDomain {
     local(*db, $options, $type, $OldObject, $NewObject, $domain)=@_;
     
@@ -270,7 +370,7 @@ sub AuthorizeDomain {
     
     if (($domain!~ /\./) && ($options & $NEWOPTION)) {
        
-       $returncode=$E_HIER_AUTHFAIL;
+       return $E_HIER_AUTHFAIL;
 
     }
     
@@ -297,7 +397,7 @@ sub AuthorizeDomain {
     
     # we didn't find a parent object
     
-    return $E_HIER_AUTHFAIL;   
+    return $O_OK;
           
 }    
 
