@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: indexdb.pl,v 2.5.2.1 1998/11/06 15:06:15 roman Exp $
+# $Id: indexdb.pl,v 2.7 1999/01/12 09:57:05 roman Exp $
 #
 #	$RCSfile: indexdb.pl,v $
-#	$Revision: 2.5.2.1 $
+#	$Revision: 2.7 $
 #	$Author: roman $
-#	$Date: 1998/11/06 15:06:15 $
+#	$Date: 1999/01/12 09:57:05 $
 
 require "getopts.pl";
 
@@ -34,7 +34,7 @@ require "rconf.pl";
 require "misc.pl";
 require "donetdbm.pl";
 
-&Getopts('cs:t:T:V');
+&Getopts('cs:t:T:Vb');
 
 local($conffile) = $ENV{"RIPEDBCNF"};
 $conffile = $RIPEConfig{DEFCONFIG} unless $conffile;
