@@ -1,3 +1,4 @@
+
 # maintainer.pl - implements all functions associated with the maintainer
 # attribute, as defined in ripe-??
 #
@@ -21,12 +22,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: maintainer.pl,v 2.5.2.5 1998/11/25 10:59:03 roman Exp $
+# $Id: maintainer.pl,v 2.10 1999/05/31 15:24:44 roman Exp $
 #
 #	$RCSfile: maintainer.pl,v $
-#	$Revision: 2.5.2.5 $
+#	$Revision: 2.10 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:59:03 $
+#	$Date: 1999/05/31 15:24:44 $
 
 # There is a few global variables it will use for authorisation:
 # 
@@ -85,21 +86,27 @@ sub Maintainer {
     # special case - adding maintainers to the TEST database
     # which are maintained by themselves - skip authorization
 
-    if (($options & $NEWOPTION) && 
-	($opt_T)               &&
-	($mntners =~ /$NewObject{"mt"}/)) {
+    return 1 if ($options & $NEWOPTION) 
+	     && ($opt_T)                 
+	     && ($mntners =~ /$NewObject{"mt"}/);
+
+# see comment about notifying maintainers near the end of this function
+
+#    if (($options & $NEWOPTION) && 
+#	($opt_T)               &&
+#	($mntners =~ /$NewObject{"mt"}/)) {
+#
+#	# Notify maintainers
+#	if ($othermntners) {
+#	    &NotifyMaintainers(*OldObject, *NewObject, $othermntners);
+#	}
+#	else {
+#	    &NotifyMaintainers(*OldObject, *NewObject, "");
+#	}	
+#	return 1;
+#    }
 
-	# Notify maintainers
-	if ($othermntners) {
-	    &NotifyMaintainers(*OldObject, *NewObject, $othermntners);
-	}
-	else {
-	    &NotifyMaintainers(*OldObject, *NewObject, "");
-	}	
-	return 1;
-    }
 
-    #
     # check authorization if no override
 
     if (!($options & $OVERRIDEOPTION)) {
@@ -117,6 +124,7 @@ sub Maintainer {
 	
        }
     
+
        if (!$status) {
 
           #
@@ -137,14 +145,17 @@ sub Maintainer {
     }
     
     #
-    # Notify maintainers
+    # Notify maintainers removed out of this function
+    # we don't want to notify maintainers about the success 
+    # while hierarchical authorisation is still to come and could fail
+    # And this is side effect after all
 
-    if ($othermntners) {
-       &NotifyMaintainers(*OldObject, *NewObject, $othermntners);
-    }
-    else {
-       &NotifyMaintainers(*OldObject, *NewObject, "");
-    }
+#    if ($othermntners) {
+#       &NotifyMaintainers(*OldObject, *NewObject, $othermntners);
+#    }
+#    else {
+#       &NotifyMaintainers(*OldObject, *NewObject, "");
+#    }
 	
     return 1;
     
@@ -464,9 +475,17 @@ sub ForwardTmpFile {
 sub WriteForwardHeader {
     local($filehandle, $email) = @_;
 
-    $email = $DEFMAIL if $TESTMODE;
+    if ($TESTMODE) {
+	$origemail = $email;
+	$email = $DEFMAIL;
+        print $filehandle $FWHEADER, "To: ", $email, "\n";
+        print $filehandle "X-Forward-Orig-Recipient: ", $origemail, "\n\n";
+        print $filehandle $FWTXT;
+    }
+    else {
+        print $filehandle $FWHEADER, "To: ", $email, "\n\n", $FWTXT;
+    }
 
-    print $filehandle $FWHEADER, "To: ", $email, "\n\n", $FWTXT;
     
     if ($NETWORKUPDATE) {
        print $filehandle $FWNETWORKTXT, "\n";
