@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: misc.pl,v 2.14.2.4 1998/11/25 10:34:05 roman Exp $
+# $Id: misc.pl,v 2.17 1999/05/31 14:45:30 roman Exp $
 #
 #	$RCSfile: misc.pl,v $
-#	$Revision: 2.14.2.4 $
+#	$Revision: 2.17 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:34:05 $
+#	$Date: 1999/05/31 14:45:30 $
 #
 
 require "defines.pl";
@@ -78,6 +78,7 @@ sub ReplaceGlobalVars {
     $text=~ s/\$REFERHOST/$REFERHOST/go;
     $text=~ s/\$REFERPORT/$REFERPORT/go;
     $text=~ s/\$REFERMSG/$REFERMSG/go;
+    $text=~ s/\$REFERQUERY/$REFERQUERY/go;
 }
 
 sub MakeRegular {
@@ -638,6 +639,7 @@ sub isnichandle {
     #    - -ORG organization InterNIC handles
     #    - -ARIN ARIN handles
     #    - -ORG-ARIN ARIN handles
+    #    - -RIPN RIPN handles
     
   my $handle = shift;
   
@@ -663,6 +665,7 @@ sub isnichandle {
   # Internic used -ORG suffix
   # ARIN use -ARIN suffix
   # ARIN also use -ORG-ARIN suffix
+  # RIPN use -RIPN suffix
   #
   
   if ($handle =~ /^([A-Z]{2,$MAXLENGTHINITIALS})([1-9]\d{0,5})?(-\S+)?$/) {
@@ -692,6 +695,7 @@ sub isnichandle {
 		 ($suffix eq 'ORG') ||
                  ($suffix eq 'ARIN') ||
                  ($suffix eq 'ORG-ARIN') ||
+		 ($suffix eq 'RIPN') ||
 		 ($suffix eq 'AP')
 		 );
   }
