@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: notify.pl,v 2.7.2.3 1998/11/25 10:59:04 roman Exp $
+# $Id: notify.pl,v 2.10 1999/05/31 14:45:31 roman Exp $
 #
 #	$RCSfile: notify.pl,v $
-#	$Revision: 2.7.2.3 $
+#	$Revision: 2.10 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:59:04 $
+#	$Date: 1999/05/31 14:45:31 $
 
 
 require "encmp.pl";
@@ -187,9 +187,16 @@ sub NotifyTmpFile {
 sub WriteNotifyHeader {
     local($filehandle, $notifier)=@_;
 
-    $notifier=$DEFMAIL if $TESTMODE;
-    
-    print $filehandle $NHEADER, "To: ", $notifier, "\n\n", $NOTITXT;
+    if ($TESTMODE) {
+	$orignotifier = $notifier;
+	$notifier=$DEFMAIL;
+	print $filehandle $NHEADER, "To: ", $notifier, "\n";
+	print $filehandle "X-Notify_Orig_Recipient: ", $orignotifier, "\n\n";
+	print $filehandle $NOTITXT;
+    }
+    else {
+        print $filehandle $NHEADER, "To: ", $notifier, "\n\n", $NOTITXT;
+    }
     
     if ($NETWORKUPDATE) {
        print $filehandle $NOTINETWORKTXT, "\n";
