@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: processdata.pl,v 2.11.2.5 1998/11/25 10:59:05 roman Exp $
+# $Id: processdata.pl,v 2.15 1999/05/28 16:19:48 roman Exp $
 #
 #	$RCSfile: processdata.pl,v $
-#	$Revision: 2.11.2.5 $
+#	$Revision: 2.15 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:59:05 $
+#	$Date: 1999/05/28 16:19:48 $
 
 
 @INC = ("LIBDIR", @INC);
@@ -109,7 +109,7 @@ sub processdata {
     local($type,$key,$value,$reordered,$dbstat,$parsestat);
     local($options,$codes,$overrideattr,$deleteattr,@autonichandles);
 
-#    &dpr("\$FROM = $FROM, \$input = $input, \$output = $output\n");
+    &dpr("\$FROM = $FROM, \$input = $input, \$output = $output\n");
     
     while(1) {
 
@@ -176,14 +176,14 @@ sub processdata {
 	   }
 	
 	   if (defined($entry{"uo"})) {
-	
-	      $options|=$OVERRIDEOPTION;
-#	      &dpr("override option set\n");
-	      $overrideattr=delete($entry{"uo"});
-	                    
+	       &dpr("override entry: ".$entry{"uo"}."\n");
+	       $options |= $OVERRIDEOPTION;
+	       $options |= $OVERRIDEINTEGRITY 
+		   if ($entry{"uo"} =~ /integrity/i);
+	       $overrideattr = delete($entry{"uo"});
 	   }
 	   else {
-	      $overrideattr=undef;
+	      $overrideattr = undef;
 	   }
            
         }
@@ -302,11 +302,11 @@ sub processdata {
 	   }
 	
 	   if (defined($entry{"uo"})) {
-	
-	      $options|=$OVERRIDEOPTION;
-#	      &dpr("override option set\n");
-	      $overrideattr=delete($entry{"uo"});
-	                    
+	       &dpr("override entry: ".$entry{"uo"}."\n");
+	       $options |= $OVERRIDEOPTION;
+	       $options |= $OVERRIDEINTEGRITY 
+		   if ($entry{"uo"} =~ /integrity/i);
+	       $overrideattr = delete($entry{"uo"});
 	   }
         
            #
@@ -336,7 +336,7 @@ sub processdata {
 	}
 	elsif (($dbstat!=$O_ERROR) && ($dbstat!=$O_OK) && ($dbstat!=$E_NOOP)) { 
 	      
-	    &adderror(*entry, $MESSAGE[$dbstat]);
+	    &adderror(*entry, eval $MESSAGE[$dbstat]);
 	     
 	    $haserror++;
 	      
@@ -378,7 +378,7 @@ sub processdata {
 	elsif (&haswarning(*entry)) {
 	   
 	   &printstat($output, *entry, $type, $options | $OKOPTION);
-	   &enwrite($output,*entry,1,1,1);
+ 	   &enwrite($output,*entry,1,1,1);
 	   print $output "\n";
 	   
 	}
@@ -636,8 +636,8 @@ sub dbupdate {
 	} elsif ($pgpsigstatus == 0) { # PGP signature not OK, ignore this part
           $PGP_signed = undef;
 
-	  print ACK "*** Ignoring PGP signed part with BAD signature "
-	      . "from key ID $pgpsigid\n\n";
+	  print ACK "*** Ignoring PGP signed part with BAD signature"
+	      . ($pgpsigid ? " from key ID $pgpsigid" : "") . "\n\n";
 	  $haserror = $somethingfound = 1;
 
 	} elsif ($pgpsigstatus == 1) { # signature by unknown keyID
@@ -720,6 +720,7 @@ sub dbupdate {
 
   	  if ($TESTMODE) {
 	    push @ack, "To: ", $DEFMAIL, "\n";
+	    push @ack, "X-Ack-Orig-Recipient: ", $REPLYTO, "\n";
 	  }
 	  else {
 	    #
@@ -756,13 +757,11 @@ sub dbupdate {
 
       if ($somethingfound) {
 	push @ack, <ACK>;
-
-        # include diagnostics from Subject: parser
-        push @ack, @subj_ans;    
       } else {
 	push @ack, "*** No objects were found ***\n" unless ($NETWORKUPDATE);
       }
-
+      # include diagnostics from Subject: parser
+      push @ack, @subj_ans;    
     }
 
 #    if ($somethingfound) {
