@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: rconf.pl,v 2.10.2.5 1998/11/24 09:40:30 roman Exp $
+# $Id: rconf.pl,v 2.17 1999/05/31 14:45:32 roman Exp $
 #
 #	$RCSfile: rconf.pl,v $
-#	$Revision: 2.10.2.5 $
+#	$Revision: 2.17 $
 #	$Author: roman $
-#	$Date: 1998/11/24 09:40:30 $
+#	$Date: 1999/05/31 14:45:32 $
 #
 #       This routine reads all parameters from the configuration file
 #       into scalars or associative arrays of the same name (uppercase).
@@ -48,8 +48,6 @@ require "read_objs.pl";
 sub rconf {
     local($confname) = @_;
 
-    local ($i);
-
     #
     # set the program name correctly
 
@@ -70,18 +68,44 @@ sub rconf {
     # set a safe umask
     
     umask(022);
+
+    rconfreadfile($confname);
+
+    rconfprocess();
+}
+
+sub rconfreadfile {
+    my($confname) = @_;
+    my($i);
+    my($newconf);
+    local *CONF;
     
     open(CONF, $confname) || &fatalerror("rconf: cannot open config \"$confname\", $!");
 
+    # print STDERR "Reading configuration from $confname\n";
+
     while (<CONF>) {
 	
 	study $_;
-	
+
 	next if (/^\#/);
 	next if (/^\s*$/);
-	
+
+	# print STDERR "++++ $_";
+		
 	last if (/^ENDCONF/);
 
+	if (/^INCLUDE\s+(\S+)/) {
+	    $newconf=$1;
+	    if($newconf !~ m|/|)
+		{
+		$newconf=substr($confname,0,rindex($confname,"/")+1) . $newconf;
+		}
+	    &rconfreadfile($newconf);	    
+	    next;
+	}
+
+
         if (/^COUNTRY\s+(..)\s+(..)/) { 
 	    $COUNTRY{$1}=$1; $COUNTRY{$2}=$1; 
 	    next;
@@ -89,8 +113,8 @@ sub rconf {
 
         if (s/^OBJ\s+(\S\S)\s+(\S+)\s+//) {
            
-           $type=$1;
-           $field=$2;
+           my $type=$1;
+           my $field=$2;
            
            s/\s+/ /g;
            s/ $//;
@@ -207,16 +231,20 @@ sub rconf {
 	   
 	}
 	
+	# the following 3 options allow a LIST of IP's 
+	# to be specified on a line
 	
-	if (/^GETUPDATESFROM\s+(\S.*\S)$/) { 
+	if (/^GETUPDATESFROM\s+(.*)/) { 
 	    push(@GETUPDATESFROM, split(/\s+/, $1)); next; 
 	}
-	if (/^DENYWHOISACCESS\s+(\S.*\S)$/) { 
+	if (/^DENYWHOISACCESS\s+(.*)/) { 
 	    push(@DENYWHOISACCESS, split(/\s+/, $1)); next;
 	}
-	if (/^WHOISUPDFROM\s+(\S.*\S)$/) { 
+	if (/^WHOISUPDFROM\s+(.*)/) { 
 	    push(@WHOISUPDFROM, split(/\s+/, $1)); next; 
 	}
+	if (/^BINDADDR\s+(\d+\.\d+\.\d+\.\d+)\s*$/) { $BINDADDR = $1; next; }
+	if (/^BINDPORT\s+(\d+)\s*$/) { $BINDPORT = $1; next; }
 	if (/^MAILTXT\s+(.*)/) { $MAILTXT.=$1."\n"; next;}
 	if (/^ACKSIG\s+(.*)/) { $ACKSIG=$ACKSIG.$1."\n"; next;}
 	if (/^RIGHTS\s+(.*)/) { $RIGHTS.=$1."\n"; next; }
@@ -250,7 +278,12 @@ sub rconf {
 	    { $REFERRALLOOPERRORTXT.=$1."\n"; next;}
 	if (/^REFERRALTIMEOUTTXT\s+(.*)/) 
 	    { $REFERRALTIMEOUTTXT.=$1."\n"; next;}
+	if (/^REFERRALTRUNCTXT\s+(.*)/) 
+	    { $REFERRALTRUNCTXT.=$1."\n"; next;}
+	if (/^REFERRALENDTXT\s+(.*)/)
+	    { $REFERRALENDTXT.=$1."\n"; next;}
 	if (/^REFERRALTIMEOUT\s+(\d+)/) {$REFERRALTIMEOUT = $1; next}
+	if (/^REFERRALMAXLINES\s+(\d+)/) {$REFERRALMAXLINES = $1; next}
 
 	
 	#
@@ -293,6 +326,13 @@ sub rconf {
 	   next;
 	}
 
+        if (/^ALLOCMNT\s+(.+)$/) {
+	   foreach (split(/\s+/, $1)) {
+	      $ALLOCMNT{$_}=1;
+	   }
+    	   next;
+        }
+
 	# CROSSNOTIFYSOURCES <source> <list of sources to search for conflicts>
 	# $::CROSSNOTIFYSOURCES - hash indexed on source name
 	#                      - values are refs to arrays of source names
@@ -389,6 +429,7 @@ sub rconf {
 	if (/^OBJDESC\s+(\S+)/) {$OBJDESC=$1; next }
 
 	if (/^QRYLOG\s+(\S+)/) { $LOGFILE{"QRYLOG"}=$1; next; }
+	if (/^QRY2LOG\s+(\S+)/) { $LOGFILE{"QRY2LOG"}=$1; next; }
 	if (/^ERRLOG\s+(\S+)/) { $LOGFILE{"ERRLOG"}=$1; next; }
 	if (/^AUDITLOG\s+(\S+)/) { $LOGFILE{"AUDITLOG"}=$1; next; }
 	if (/^UPDLOG\s+(\S+)/) { $LOGFILE{"UPDLOG"}=$1; next; }
@@ -428,6 +469,12 @@ sub rconf {
 	
     }
     close(CONF);
+
+
+}
+
+
+sub rconfprocess{
     
     local($j,@tmp);
     local(%ALLPOINTSTO)=();
