@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: rfc822.pl,v 2.3.2.7 1998/11/25 10:34:07 roman Exp $
+# $Id: rfc822.pl,v 2.4 1998/12/09 14:39:24 roman Exp $
 #
 #	$RCSfile: rfc822.pl,v $
-#	$Revision: 2.3.2.7 $
+#	$Revision: 2.4 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:34:07 $
+#	$Date: 1998/12/09 14:39:24 $
 
 # Takes filehandle from input mail to read as argument
 #
@@ -78,14 +78,14 @@ sub parsesubject #
     # 0. check contents.
     for $i ( split(' ',$SUBJECT)  )   
     {
-	if ( $i !~ /^($keywords)$/)    
+	if ( $i !~ /^($keywords)$/i)    
 	{
 	    push @unknown_keywords, $i;
-	    print STDERR "parsesubject: unknown keyword $i\n" if $opt_V;
+	    &dpr("unknown keyword $i\n");
 	}
 	else
 	{   
-	    push @subjectwords, $i;
+	    push @subjectwords, uc $i;
 	}
     }
     
