@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: syncdb.pl,v 2.13.2.5 1998/11/25 10:34:09 roman Exp $
+# $Id: syncdb.pl,v 2.16 1999/02/02 11:37:53 marek Exp $
 #
 #	$RCSfile: syncdb.pl,v $
-#	$Revision: 2.13.2.5 $
-#	$Author: roman $
-#	$Date: 1998/11/25 10:34:09 $
+#	$Revision: 2.16 $
+#	$Author: marek $
+#	$Date: 1999/02/02 11:37:53 $
 
 # This is a client that will update objects read from a file directly
 # in the database, without interference of updated.
@@ -54,7 +54,7 @@ require "whoisqry.pl";
 
 ## parse command line
 
-Getopt::Std::getopts('h:p:s:u:p:V');
+Getopt::Std::getopts('h:p:s:u:p:Vb');
 
 $::WHOIS_HOST = $::RIPEConfig{WHOISHOST};
 $::WHOIS_HOST = $opt_h if $opt_h;
@@ -80,7 +80,8 @@ Where:
 -s source        - which source to query for
 -u period:delay  - the program will run for 'period' seconds and
                    will do a query every 'delay' seconds
-
+-V               - verbose output
+-b               - prints a lot of useless debugging information
 EOF
 
   exit 1;
@@ -244,11 +245,11 @@ sub doaction {
 
        if ($dbstat == $E_NOOP) {
           print STDERR "ERROR, incomingserial ($action: $entry{$type}): ", $LOGFILE{"SERIALINCOMINGDIR"}, $serial, " [NOOP]\n\n";
-          &skiperrorserial(*entry,$action,$source,$MESSAGE[$dbstat]);
+          &skiperrorserial(*entry,$action,$source,eval $MESSAGE[$dbstat]);
        }
        elsif ($dbstat!=$OK) {
-          print STDERR "ERROR, incomingserial ($action: $entry{$type}): ", $LOGFILE{"SERIALINCOMINGDIR"}, $serial, " ", $MESSAGE[$dbstat], "\n\n";
-          &skiperrorserial(*entry,$action,$source,$MESSAGE[$dbstat]);
+          print STDERR "ERROR, incomingserial ($action: $entry{$type}): ", $LOGFILE{"SERIALINCOMINGDIR"}, $serial, " ", eval $MESSAGE[$dbstat], "\n\n";
+          &skiperrorserial(*entry,$action,$source,eval $MESSAGE[$dbstat]);
        }
        else {
 #          &dpr("OK, ($action: $entry{$type}) serial: $serial\n");
