@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: syntax.pl,v 2.11.2.6 1998/11/25 10:34:10 roman Exp $
+# $Id: syntax.pl,v 2.24 1999/06/01 11:34:50 marek Exp $
 #
 #	$RCSfile: syntax.pl,v $
-#	$Revision: 2.11.2.6 $
-#	$Author: roman $
-#	$Date: 1998/11/25 10:34:10 $
+#	$Revision: 2.24 $
+#	$Author: marek $
+#	$Date: 1999/06/01 11:34:50 $
 #
 #       ARGUMENTS:      *ASSOC object
 #       RETURNS:        INTEGER object_status
@@ -54,6 +54,8 @@ sub requiredsyntaxcheck {
 
     local($rtcode)=$O_OK;
 
+    &dpr("\n");
+
     if (!$type) {	
        
        &adderror(*object, "unknown object type");
@@ -68,23 +70,19 @@ sub requiredsyntaxcheck {
     # print STDERR $object{"so"}, $CANUPD{$object{"so"}}, "\n";
     
     if ($object{"so"}) {
-    
-       if (!$DBFILE{$object{"so"}}) {
-    
-          &adderror(*object, "unknown source \"".$object{"so"}."\"");
-        
-          $rtcode=$O_ERROR;
-       
-       }
-    
-       if (!$CANUPD{$object{"so"}}) {
-    
-          &adderror(*object,"cannot update entry with source \"".$object{"so"}."\"");
-       
-          $rtcode=$O_ERROR;
-    
-       }
-       
+	if (!$DBFILE{$object{"so"}}) {
+	    &adderror(*object, "unknown source \"".$object{"so"}."\"");
+	    $rtcode=$O_ERROR;
+	}
+	if (!$CANUPD{$object{"so"}}) {
+	    &adderror(*object,"cannot update entry with source \"" .
+		      $object{"so"} . "\"");
+	    $rtcode=$O_ERROR;
+	}
+    }
+    else {
+	&adderror(*object, "mandatory field \"source\" missing");
+	$rtcode = $O_ERROR;
     }
     
     #
@@ -628,9 +626,18 @@ sub dosyntax {
 	}	
 	elsif ($authstr[0] eq "MAIL-FROM") {
 	    local($regex) = $value;
-	    $regex =~ s/^\s*MAIL\-FROM\s*//;
+	    $regex =~ s/^\s*MAIL\-FROM\s*//;	# del all up to regex
+	    $regex =~ s/\s+$//;			# del whitespaces at the end
+	    $regex =~ s/\\?\@/\Q\@\E/g;         # quote '@'s for perl5
+	
+	    if ($regex =~ /^$/) {
+		return $O_ERROR, "regular expression missing from MAIL-FROM attribute";
+	    }
 
-	    $regex =~ s/\\?\@/\Q\@\E/g;   # quote '@'s for perl5
+	    if ($regex =~ /\s/) {
+		return $O_WARNING, "whitespace found " . 
+			"inside regular expression in MAIL-FROM attribute";
+	    }
 
 	    # Check the given regexp is valid.
 	    eval { m/$regex/ };
@@ -644,7 +651,7 @@ sub dosyntax {
 	}
         elsif ($authstr[0] =~ /^PGPKEY/) {
             if ($authstr[0] !~ /^\s*PGPKEY-[0-9a-fA-F]{8}\s*$/) {
-               return $O_ERROR, "syntax error in \"$ATTL{$key}";
+               return $O_ERROR, "syntax error in \"$ATTL{$key}\"";
             } else {
                 return $O_OK;
             }
@@ -1266,6 +1273,13 @@ sub dosyntax {
 	    "syntax error in \"$ATTL{$key}\" ".
 		"- \"$value\" is not in \(RFC822\) format";
 	}
+	
+        if( $value =~ /$AUTOBOX/ ) {
+            return $O_ERROR,
+            "invalid address in \"$ATTL{$key}\" ".
+                "- \"$value\" ";
+        }
+
 	return $O_OK;
     }
 
@@ -1581,6 +1595,39 @@ sub dosyntax {
           
        }
              
+ 
+       local($fullipv6prefix,$prefixlength);
+       ($fullipv6prefix,$prefixlength) = split('/',$value);
+       local(@words);
+       @words = split(':',$fullipv6prefix);
+  
+       if($words[0] !~ /[23][0-9A-Fa-f]{3}/ ){ #only unicast addresses can be registered
+
+           return ($O_ERROR, "error in \"$ATTL{$key}\" - only global unicast addresses can be registered\n");
+ 
+       }
+ 
+       if($words[0] eq '2001'){  # if this is TLA 0x0001
+ 
+         if($prefixlength < 4 || $prefixlength > 64){
+ 
+           return ($O_ERROR, "error in \"$ATTL{$key}\" - invalid ipv6 prefix value specified\n");  
+ 
+         }
+ 
+       }
+       else{
+          if($prefixlength < 4 || $prefixlength >64 || ( $prefixlength >= 16 && $prefixlength <= 24 )){
+ 
+            return ($O_ERROR, "error in \"$ATTL{$key}\" - invalid ipv6 prefix value specified\n");  
+ 
+          }
+          if(hex($words[1]) > hex('FF')){ # reserved field is _not_ zeros
+ 
+            return ($O_ERROR, "error in \"$ATTL{$key}\" - reserved field must be filled with zeros\n");  
+
+          }
+       }
        
        #
        # remove long ranges of zeroes
@@ -1798,6 +1845,7 @@ sub dosyntax {
 		       $warningmsg .= "maintainer $mntner does not provide "
 			   . "adequate protection for\nPGP key certificate "
 			   . "object -- consider upgrading auth to PGPKEY\n";
+		       last;
 		    }
 	         }
 	      }
@@ -1903,6 +1951,8 @@ sub dosyntax {
        }
        return $O_ERROR, "syntax error in \"$ATTL{$key}\"" 
 	   if (!&isnichandle($value));
+       return $O_ERROR, "reserved word $1 used as nic handle" 
+	   if ($value =~ /^(auto\d*)/i);
        return $O_OK;
     }
     
@@ -2084,8 +2134,8 @@ sub dosyntax {
           }
 	  else {
 	      return $O_ERROR,
-	          "syntax error in \"$ATTL{$key}\"\n" .
-		  "$name is nor nic handle neither auto nic handle";
+	          "syntax error in \"$ATTL{$key}\":\n" .
+		  "\"$name\" is neither nic handle nor auto nic handle";
 	  }
        }
        $object{$key}=join("\n", @names);
@@ -2230,21 +2280,35 @@ sub dosyntax {
        
        # for backwards compatibility, must be BEFORE other checks
        
-       if ($value =~ /^D(ELEGATED)?$/i) {
+       if ($type eq "in") {
+	  if ($value =~ /^D(ELEGATED)?$/) {
           
-          $value="ALLOCATED UNSPECIFIED";
-          $object{$key}=$value;
+              $value="ALLOCATED UNSPECIFIED";
+              $object{$key}=$value;
           
-          return $O_WARNING, "\"$ATTL{$key}\" changed to \"$object{$key}\"";
-       
+              return $O_WARNING, "\"$ATTL{$key}\" changed to \"$object{$key}\"";
+          }
+
+          if ( $value =~ /^ASSIGNED (PI|PA)$/ ) {
+              return $O_OK;
+          }
+
+	  if ( $value =~ /^ALLOCATED (PI|PA|UNSPECIFIED)$/) {
+	      if( ! $ALLOCMNT{$object{"mb"}} ) {
+		return $O_ERROR, 
+			"Status ALLOCATED can be set only by the following mntner(s):\n\t" .
+			join("\n\t",sort keys %ALLOCMNT);
+	      }
+              return $O_OK;
+          }
        }
 
-       if (($value =~ /^ASSIGNED (PI|PA)$/) ||
-           ($value =~ /^ALLOCATED (PI|PA|UNSPECIFIED)$/)) {
-           
-           return $O_OK;
+       if ($type eq "i6") {
+
+                return $O_ERROR, "\"$ATTL{$key}\" is a generated attribute in inet6num objects";
+      
        }
-       
+
        return $O_ERROR, "\"$ATTL{$key}\" has an illegal value";
     
     }
