@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: syslog.pl,v 2.3 1998/07/15 18:01:42 joao Exp $
+# $Id: syslog.pl,v 2.5 1999/05/28 16:19:49 roman Exp $
 #
 #	$RCSfile: syslog.pl,v $
-#	$Revision: 2.3 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:42 $
+#	$Revision: 2.5 $
+#	$Author: roman $
+#	$Date: 1999/05/28 16:19:49 $
 #
 #	It allows you to write to various logfiles defined in general config
 #	
@@ -41,7 +41,7 @@ sub fatalerror {
 
    # log in as many places as possible...
 
-   local($error)="Fatal error: ".join("", @_)."\n";
+   local($error)="Fatal error: ".join("", @_)." PID: $$\n";
 
    if (&syslog("ERRLOG", $error)) {
       
@@ -60,18 +60,22 @@ sub fatalerror {
 }
 
 sub syslog {
-    local($log, $string) = @_;
+    local($log, $string, $nostamp) = @_;
+    local($date);
 
-    # Get the time
-
-    local($s, $m, $h, $md, $mo, $y, $wd, $yd, $is) = localtime(time);
-    local($thismonth) = (Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec)[$mo];
-
-    $s = "0".$s unless $s > 9;
-    $m = "0".$m unless $m > 9;
-    $h = "0".$h unless $h > 9;
-
-    local($date) = sprintf("%3s %2d %2s:%2s:%2s", $thismonth,$md,$h,$m,$s);
+    if ($nostamp) {
+	$date = "";
+    }
+    else {
+	# Get the time
+	local($s, $m, $h, $md, $mo, $y, $wd, $yd, $is) = localtime(time);
+	local($thismonth) = 
+	    (Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec)[$mo];
+	$s = "0".$s unless $s > 9;
+	$m = "0".$m unless $m > 9;
+	$h = "0".$h unless $h > 9;
+	$date = sprintf("%3s %2d %2s:%2s:%2s", $thismonth,$md,$h,$m,$s);
+    }
 
     #
     # Now we got a date let's open the logfile
