@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: updatecheck.pl,v 2.2.2.3 1998/11/25 10:34:11 roman Exp $
+# $Id: updatecheck.pl,v 2.4 1999/05/28 16:19:49 roman Exp $
 #
 #	$RCSfile: updatecheck.pl,v $
-#	$Revision: 2.2.2.3 $
+#	$Revision: 2.4 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:34:11 $
+#	$Date: 1999/05/28 16:19:49 $
 
 require "defines.pl";
 require "adderror.pl";
@@ -124,7 +124,8 @@ sub updatecheck {
                 
     return $E_NOAUTOUPDATE if ((!($options & $OVERRIDEOPTION)) && 
                                ($OBJMAND{$type}=~ /\bmb\b/) && 
-                               (!defined($oldobject{"mb"})));
+                               (!defined($oldobject{"mb"})) &&
+			       (!($options & $NEWOPTION)));
 
     #
     # If this is a maintainer object, bounce it of to the human mailbox
@@ -206,9 +207,22 @@ sub updatecheck {
     # And now the hierarchical authorization
     # only for creation right now...
        
-    return $E_HIER_AUTHFAIL if ($O_OK!=&HierarchicalAuthorization(*db, *oldobject, *newobject, $type, $options));
+    $hierstat = 
+	&HierarchicalAuthorization(*db, *oldobject,*newobject, $type, $options);
+
+    if ($hierstat == $O_OK) {
+	&NotifyMaintainers(*oldobject, *newobject, "");
+	return $returncode;
+    }
+    else {
+	return $E_HIER_AUTHFAIL;
+    }
+
+#    return $E_HIER_AUTHFAIL 
+#    if ($O_OK != &HierarchicalAuthorization
+#	(*db, *oldobject, *newobject, $type, $options));
     
-    return $returncode;
+#    return $returncode;
     
 }
 
