@@ -20,25 +20,26 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: whoisd.pl,v 2.21.2.11 1998/11/25 10:59:06 roman Exp $
+# $Id: whoisd.pl,v 2.30 1999/05/31 10:57:07 roman Exp $
 #
 #	$RCSfile: whoisd.pl,v $
-#	$Revision: 2.21.2.11 $
+#	$Revision: 2.30 $
 #	$Author: roman $
-#	$Date: 1998/11/25 10:59:06 $
+#	$Date: 1999/05/31 10:57:07 $
 #
 
 #
 # Usage:
 #
-# whoisd [-V] [-D] [-p port] [[WhoisOptions] SearchString]
+# whoisd [-V] [-b] [-D] [-p port] [[WhoisOptions] SearchString]
 #
 # where:
 #
 # -D       - run as daemon instead of from inetd 
 #            Note: -D should always be set, inetd functionality is untested
 # -p port  - bind to port 'port'
-# -V       - run in debug/verbose mode
+# -V       - run in verbose mode
+# -b       - run in debug mode
 # 
 # whoisd will not run as daemon if a SearchString is specified
 # but instead perform a lookup for the SearchString
@@ -200,8 +201,8 @@ sub findsplitdbs {
     local(*keys, @preselection)=@_;
     local(@searchdb)=();
 
-#    &dpr("called with \@keys = ", join(" ", @keys), 
-#	 "\@preselection = ", join(" ", @preselection), "\n");
+    &dpr("called with \@keys = ", join(" ", @keys), 
+	 "\@preselection = ", join(" ", @preselection), "\n");
 
     @preselection = grep($CLASSLESSDBS{$_}, @preselection) 
 	if (scalar(grep(/^$VALIDPREFIXKEY$/o, @keys)) == scalar(@keys));
@@ -283,7 +284,7 @@ sub findsplitdbs {
 	   push(@searchdb, $j);
        }
     } # end of loop foreach @preselection
-#    &dpr("\@searchdb = (", join(" ", @searchdb), ")\n");
+    &dpr("\@searchdb = (", join(" ", @searchdb), ")\n");
     return @searchdb;
 }
 
@@ -341,13 +342,17 @@ sub referenceorder {
 sub lookupandprint {
 
     local($output, *db, *keys, *references, 
-	  $types, *result, $options, $name, $rhost)=@_;
+	  $types, *result, $options, $name, $rhost) = @_;
 
-#    &dpr("called with:",
-#	 "\$output = $output, \$db = $db, \@db = ", join(" ", @db),
-#	 "\nkeys: ", join("*", @keys), " options: $options ",
-#	 "\nreferences keys: ", join(" ", keys %references),
-#	 "\nreferences values: ", join(" ", values %references), "\n");
+    local(*chopped_keys);
+
+    @chopped_keys = @keys;
+
+    &dpr("called with:",
+	 "\$output = $output, \$db = $db, \@db = ", join(" ", @db),
+	 "\nkeys: ", join("*", @keys), " options: $options ",
+	 "\nreferences keys: ", join(" ", keys %references),
+	 "\nreferences values: ", join(" ", values %references), "\n");
 	 
     # it makes the code easier if we call with empty lists...
     return 0 if (!@keys);
@@ -358,12 +363,12 @@ sub lookupandprint {
     
     local($i,$key,$offset,$attribute,$newtype,@object);
     
-#    &dpr("keys: ", join(",",@keys), " options: $options types: $types ",
-#         "result: $result fast: ",$options & $FASTOPTION,
-#         " nonrecursive: ",$options & $NONRECURSIVEOPTION,"\n");
+    &dpr("keys: ", join(",",@keys), " options: $options types: $types ",
+         "result: $result fast: ",$options & $FASTOPTION,
+         " nonrecursive: ",$options & $NONRECURSIVEOPTION,"\n");
 
     # Check if we are looking for domains (checks the filename in the db 
-    # typeglob, so it doesn't work for non-spilt databases)
+    # typeglob, so it doesn't work for non-split databases)
 
     my(@file_name_parts) = split /\./,$db[1];
     my($look_domain) = ($file_name_parts[-1] eq "dn") ? 1 : 0;
@@ -378,14 +383,12 @@ sub lookupandprint {
     # piece of the domain name and try again
 
     if ($look_domain) {
-	local(*keys_to_be_shortened);
-	@keys_to_be_shortened = @keys;
 	for (;;) {
-	    last if (!$keys_to_be_shortened[0]);
-	    @offsets = &dbmatch(*db, *keys_to_be_shortened, $types, $OPTS);
+	    last if (!$chopped_keys[0]);
+	    @offsets = &dbmatch(*db, *chopped_keys, $types, $OPTS);
 	    last if (@offsets);
-	    my($drop, $keep) = split(/\./, $keys_to_be_shortened[0], 2);
-	    $keys_to_be_shortened[0] = $keep;
+	    my($drop, $keep) = split(/\./, $chopped_keys[0], 2);
+	    $chopped_keys[0] = $keep;
 	}
     }
     else {
@@ -394,16 +397,7 @@ sub lookupandprint {
 
     foreach $offset (sort { $a <=> $b } @offsets ) {
 
-#    foreach $offset 
-#            (sort { $a <=> $b } 
-#                  &dbmatch(*db, *keys, $types, 
-#                           $INTERSECTIONOPTION | 
-#                           ($options & ($ALLLESSSPECIFICOPTION | 
-#                                        $MORESPECIFICOPTION | 
-#                                        $ALLMORESPECIFICOPTION | 
-#                                        $EXACTMATCHOPTION)))) {
-
-#	&dpr("offset: ", $offset, " keys: ", join("*", @keys), "\n");
+	&dpr("offset: ", $offset, " keys: ", join("*", @keys), "\n");
 	my($key) = join("\t", $offset, $db[1]);
 	next if ($DISPLAYED{$key});
 	$DISPLAYED{$key}=1;
@@ -431,13 +425,12 @@ sub lookupandprint {
 	else {
 	    $newtype=&enread($db, *entry, $offset);
 
-#	    &dpr("$newtype - $types\n");
-#	    &dpr("\%entry = " . join("*", %entry) . "\n");
+	    &dpr("$newtype - $types\n");
+	    &dpr("\%entry = " . join("*", %entry) . "\n");
 	    if ($types=~ /\b$newtype\b/) {
 		# If object is of type domain, check if it has a refer attribute
 		my($refscalar, $refarray, $refhash) = 
-		    &has_refer($name, $rhost, %entry);
-#		&dpr("\%entry = " . join("*", %entry) . "\n");
+		    &has_refer($name, $rhost, $keys[0], %entry);
 
 		if ($$refscalar) {
 		    $referred_query = 1;
@@ -450,6 +443,11 @@ sub lookupandprint {
 		}
 		else {
 		    $referred_query = 0;
+		    if ($chopped_keys[0] ne $keys[0]) {
+			$DISPLAYED{$key} = 0;
+			$printed = 0;
+			last;	# exit loop over offsets
+		    }
 		    &enwrite($output, *entry, 1, 0, 
 			     !($options & $NOSYNTACTICSUGAR));
 		}
@@ -521,8 +519,8 @@ sub whois {
 
     local($input, $output, $searchstring, $name, $rhost) = @_;
 
-#    &dpr("called with: \$input = $input, \$output = $output, ",
-#	 "\$searchstring = $searchstring, \$name = $name, \$rhost = $rhost\n");
+    &dpr("called with: \$input = $input, \$output = $output, ",
+	 "\$searchstring = $searchstring, \$name = $name, \$rhost = $rhost\n");
     
     if ($opt_t) {
        
@@ -632,14 +630,14 @@ sub whois {
 	    @sources=split(/ /, $DEFLOOK);
 	}
 	
-#	&dpr("whois - sources: ", join(",",@sources), "\n");
+	&dpr("whois - sources: ", join(",",@sources), "\n");
 	
 	if ($opt_i) {
 	    
 	    local(%done)=();
 	    local(@tmp,@pointsto,$db);
 	    
-#	    &dpr("opt_T: $opt_T opt_i: $opt_i\n");
+	    &dpr("opt_T: $opt_T opt_i: $opt_i\n");
 	    
 	    if ($opt_T) {
 		@tmp=split(/ /, $opt_T);
@@ -667,8 +665,8 @@ sub whois {
 	    @splitdbs=&findsplitdbs(*keys);
 	    @keys=&makekeys($searchstring, "", *longkeys);
 	    
-#	    &dpr("whois - searchstring: -$searchstring- keys: ",
-#		 join("*", @keys), " longkeys: ", join("*", @longkeys), "\n");
+	    &dpr("whois - searchstring: -$searchstring- keys: ",
+		 join("*", @keys), " longkeys: ", join("*", @longkeys), "\n");
 	    
 	    return 0 if (!@keys);
           
@@ -978,6 +976,15 @@ sub clearflags {
     $opt_U="";
     $opt_Version="";
 
+    $log_opt_g="";
+    $log_opt_i="";
+    $log_opt_s="";
+    $log_opt_t="";
+    $log_opt_v="";
+    $log_opt_T="";
+    $log_opt_U="";
+    $log_opt_V="";
+
 }
 
 sub getflags {
@@ -1006,6 +1013,32 @@ sub getflags {
 
 }
      
+sub getfullflags {
+
+    my @flags = ();
+
+    push(@flags, "a") if ($opt_a);
+    push(@flags, "g=$log_opt_g") if ($log_opt_g);
+    push(@flags, "i=$log_opt_i") if ($log_opt_i);
+    push(@flags, "F") if ($opt_F);
+    push(@flags, "k") if ($opt_k);
+    push(@flags, "L") if ($opt_L);
+    push(@flags, "m") if ($opt_m);
+    push(@flags, "M") if ($opt_M);
+    push(@flags, "r") if ($opt_r);
+    push(@flags, "R") if ($opt_R);
+    push(@flags, "s=$log_opt_s") if ($log_opt_s);
+    push(@flags, "S") if ($opt_S);
+    push(@flags, "t=$log_opt_t") if ($log_opt_t);
+    push(@flags, "v=$log_opt_v") if ($log_opt_v);
+    push(@flags, "T=$log_opt_T") if ($opt_Type);
+    push(@flags, "U=$log_opt_U") if ($log_opt_U);
+    push(@flags, "V=$log_opt_V") if ($opt_Version);
+
+    return join("\:", @flags);
+
+}
+
                         
 #
 # parse - parses the command line string for special options and sets
@@ -1030,22 +1063,27 @@ sub parse {
 
         if ($string =~ s/^\-g *(\S+) *//) {
             $opt_g = $1;
+	    $log_opt_g = $opt_g;
             next;
         }
         
         if ($string =~ s/^\-i *(\S+) *//) {
-           if ($opt_i) {
-              $opt_i = join(" ", $opt_i, split(/\,/, $1));
-           }
-           else {
-              $opt_i = join(" ", split(/\,/, $1));
-           }
-           next;
+	    if ($opt_i) {
+		$opt_i = join(" ", $opt_i, split(/\,/, $1));
+	    }
+	    else {
+		$opt_i = join(" ", split(/\,/, $1));
+	    }
+	    $log_opt_i = 
+		join(",", map {$ATTR{$_} ? $ATTR{$_} : $_} 
+		              split(/ /, $opt_i));
+	    next;
         }
          
         if ($string =~ s/^\-U *(\S+) +(\S+) *//) {
-           $opt_U = $1." ".$2;
-           next;
+	    $opt_U = $1." ".$2;
+	    $log_opt_U = $opt_U;
+	    next;
         }
                 
 # Patch from David replaced this, 961010, AMRM.
@@ -1068,7 +1106,7 @@ sub parse {
 
 	 if ($string =~ s/^\-s *(\S+) *//) {
             local($src)=$1;
-            
+
             $src=~ tr/a-z/A-Z/;
             
             local(@requestedsources)=split(/\,+/, $src);
@@ -1093,6 +1131,13 @@ sub parse {
             else {
                $opt_s=join(",", @acceptedsources) if (@acceptedsources);
             }
+
+	    if ($log_opt_s) {
+		$log_opt_s = join(",", $log_opt_s, @requestedsources);
+	    }
+	    else {
+		$log_opt_s = join(",", @requestedsources);
+	    }
             
             next;
         }
@@ -1100,6 +1145,7 @@ sub parse {
         
         if ($string =~ s/^\-V *([a-zA-Z]+\d+[\d\.]*) *//) {
             $opt_Version=$1;
+	    $log_opt_V = $opt_Version;
             next;
         }
         
@@ -1107,11 +1153,13 @@ sub parse {
            
            local($type);
            local(@onlysearch)=();
+	   local(@allgiven) = ();
            
            foreach $type (split(/\,+/,$1)) {
             
               $type=$ATTR{$type} if $ATTR{$type};
-           
+	      push(@allgiven, $type);
+
               if ($OBJATSQ{$type}) {
               
                  push(@onlysearch, $type);
@@ -1123,22 +1171,29 @@ sub parse {
 #                 print $output "\n% Request for unknown object type \"$ATTL{$type}\" ignored";  
 #                 &flush($output);
              	   
-		$type=$ATTL{$type} if ($ATTL{$type});
-                 alarm $KEEPOPEN if (!$commandline);
-                 print $output "\n% Request for unknown object type \"$type\" ignored\n";
-                 &flush($output);
+		  $type=$ATTL{$type} if ($ATTL{$type});
+		  alarm $KEEPOPEN if (!$commandline);
+		  print $output "\n% Request for unknown object type \"$type\" ignored\n";
+		  &flush($output);
 
               }
               
            }
            
            if ($opt_T) {
-              $opt_T=join(" ", @onlysearch);
+	       $opt_T=join(" ", $opt_T, @onlysearch);
            }
            else {
-              $opt_T=join(" ", @onlysearch);
+	       $opt_T=join(" ", @onlysearch);
            }
            
+	   if ($log_opt_T) {
+	       $log_opt_T = join(",", $log_opt_T, @allgiven);
+	   }
+	   else {
+	       $log_opt_T = join(",", @allgiven);
+	   }
+
            $opt_Type=1;
            
            next;
@@ -1147,14 +1202,14 @@ sub parse {
         
         if ($string =~ s/^\-t *(\S+) *//)  {
             $opt_t=$1;
-            
+            $log_opt_t = $opt_t;
             next;
             
         }
         
         if ($string =~ s/^\-v *(\S+) *//)  {
             $opt_v=$1;
-            
+            $log_opt_v = $opt_v;
             next;
             
         }
@@ -1290,14 +1345,16 @@ sub parse {
        
        if ($opt_i=~ /^\s*$/) {
           $name.="(".$rhost.")" if ($name ne $rhost);
-          &syslog("QRYLOG","($$) [".&getflags()."] 0 $name no valid attributes specified for -i query");
+          &syslog("QRYLOG","($$) [".&getflags()."] 0 (" 
+		. scalar (time - $startime)  
+		. "s) $name no valid attributes specified for -i query");
           &exitwhoisd(0, "% no valid attributes specified for -i query");  
        }
        
     }
 
-#    &dpr("whoisd called with flags:".&getflags()."\n");
-#    &dpr("string returned: $string\n");
+    &dpr("whoisd called with flags:".&getflags()."\n");
+    &dpr("string returned: $string\n");
     
     return $string;
     
@@ -1482,28 +1539,36 @@ sub dogetserials {
           if ($to=~ /^LAST$/i) {
              $to=$last;
              if ($from==scalar($to+1)) {
-                &syslog("QRYLOG","($$) [g] 0 $name ($rhost) $option");
+                &syslog("QRYLOG","($$) [g] 0 ("
+			. scalar (time - $startime)
+			. "s) $name ($rhost) $option");
                 &exitwhoisd(0, "% Warning (1): There are no newer updates available");  
              }
           }
                
           if (($to<$first) || ($from>$to)) {
           
-             &syslog("QRYLOG","($$) [g] 0 $name ($rhost) -g syntax error 2: $first-$last, $option");
+             &syslog("QRYLOG","($$) [g] 0 ("
+			. scalar (time - $startime)
+			. "s) $name ($rhost) -g syntax error 2: $first-$last, $option");
              &exitonerror("2: Invalid range: $from-$to don\'t exist\n");
           }
                
           if ($to>$last) {
              local($range)=++$last;
           
-             &syslog("QRYLOG","($$) [g] 0 $name ($rhost) -g syntax error 3: $first-$last, $option");
+             &syslog("QRYLOG","($$) [g] 0 ("
+			. scalar (time - $startime)
+			. "s) $name ($rhost) -g syntax error 3: $first-$last, $option");
              &exitonerror("3: Invalid range: serial(s) $range-$to don\'t exist\n");
           }
        
           if ($from<$first) {
              local($range)=--$first;
           
-             &syslog("QRYLOG","($$) [g] 0 $name ($rhost) -g syntax error 4: $first-$last, $option");
+             &syslog("QRYLOG","($$) [g] 0 ("
+		. scalar (time - $startime)
+		. "s) $name ($rhost) -g syntax error 4: $first-$last, $option");
              &exitonerror("4: Invalid range: serial(s) $from-$first don\'t exist\n");
           }
        
@@ -1523,13 +1588,17 @@ sub dogetserials {
           
        }
        else {
-          &syslog("QRYLOG","($$) [g] 0 $name ($rhost) syntax error 1: $option");
+          &syslog("QRYLOG","($$) [g] 0 ("
+		. scalar (time - $startime)
+		. "s) $name ($rhost) syntax error 1: $option");
           &exitonerror("1: Syntax error in -g argument: $option\n");
        }
     }
     else {
        &syslog("AUDITLOG", "Get serial updates authorization failure: $name ($rhost) $option");
-       &syslog("QRYLOG","($$) [g] 0 $name ($rhost) authorization failure for query $option");
+       &syslog("QRYLOG","($$) [g] 0 ("
+		. scalar (time - $startime)
+		. "s) $name ($rhost) authorization failure for query $option");
        &exitonerror("***You are not authorized to get updates***\n***please contact \<$HUMAILBOX\> for more information***");
     }
     
@@ -1542,7 +1611,9 @@ sub dowhoislookup {
    
    local($result,$query);
    local($logstr)=$name;
-   
+
+   $startime = time;
+
    if (@ARGV) {
       $logstr="direct whoisd query";
    }
@@ -1555,6 +1626,12 @@ sub dowhoislookup {
    
    for (;;) {
 
+    # start counting time for each query if -k is used
+    # otherwise just use the already initialised $startime
+
+      if ($opt_k)
+	{ $startime = time; }
+
       $result=0;
       
 
@@ -1601,7 +1678,9 @@ sub dowhoislookup {
 	  }
 	  print $output "\n\n";
 	  close($output);
-	  &syslog("QRYLOG", "($$) $logstr *DENIED* $query");
+	  &syslog("QRYLOG", "($$) [] 0 ("
+		. scalar (time - $startime)
+		. "s) $logstr *DENIED* $query");
 	  $result = 0;
 	  last;
       }
@@ -1668,8 +1747,14 @@ sub dowhoislookup {
       # Log this query
 
       local($flags)=&getflags();
+      local($fullflags) = &getfullflags();
             
-      &syslog("QRYLOG","($$) [$flags] $result $logstr - $query");
+      &syslog("QRYLOG","($$) [$flags] $result (" . scalar (time - $startime) 
+         . "s) $logstr - $query");
+
+      &syslog("QRY2LOG", "[$fullflags] $query", "notimestamp") 
+	  if ($LOGFILE{"QRY2LOG"});
+
 #      &dpr("[$flags] $result $logstr - $query\n");
       #      
       # stop querying if not keep connection open is specified
@@ -1699,6 +1784,9 @@ while ($arg=shift(@ARGV)) {
    elsif ($arg eq "-V") {
       $opt_V=1;
    }
+   elsif ($arg eq "-b") {
+      $opt_b=1;
+   }
    elsif ($arg eq "-p") {
       $opt_p=shift(@ARGV);
       die "wrong/no argument specified for \"-p\" switch\n" if ($opt_p=~ /^\s*$/);
@@ -1757,11 +1845,10 @@ if ($opt_p) {
    ($port,$proto)=&getwhoisportandproto($opt_p);
 }
 else {
-   ($port,$proto)=&getwhoisportandproto("");
+   ($port,$proto)=&getwhoisportandproto(defined($BINDPORT) ? $BINDPORT : "");
 }
 
 #&dpr("whoisd daemon ($$) - will connect to port: $port with protocol: $proto\n");
-#print STDERR "whoisd daemon ($$) - will connect to port: $port with protocol: $proto\n" if ($opt_V);
 
 socket(S, PF_INET, SOCK_STREAM, $proto) || &fatalerror("socket: $!");
 
@@ -1773,8 +1860,14 @@ socket(S, PF_INET, SOCK_STREAM, $proto) || &fatalerror("socket: $!");
 
 setsockopt(S, SOL_SOCKET, SO_REUSEADDR, 1); # || &fatalerror("setsockopt: $!");
 
-while (!bind(S, sockaddr_in ($port, INADDR_ANY))) {
+my($bindaddr);
 
+if (defined($BINDADDR)) {
+  $bindaddr = inet_aton($BINDADDR);
+}
+$bindaddr = INADDR_ANY unless defined($bindaddr);
+
+while (!bind(S, sockaddr_in ($port, $bindaddr))) {
   # max number of times to try the bind
   my $MAX = 2;
 
@@ -1788,7 +1881,6 @@ while (!bind(S, sockaddr_in ($port, INADDR_ANY))) {
     }
     else {
 #	&dpr("whoisd daemon ($$) - bind: $!, trying again after $WAIT seconds\n");
-#       print STDERR "whoisd daemon ($$) - bind: $!, trying again after $WAIT seconds\n" if ($opt_V);
        $bindcount++;
        sleep $WAIT;
     }
