@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: whoisqry.pl,v 2.3 1998/07/15 18:01:45 joao Exp $
+# $Id: whoisqry.pl,v 2.4 1998/12/09 14:39:31 roman Exp $
 #
 #	$RCSfile: whoisqry.pl,v $
-#	$Revision: 2.3 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:45 $
+#	$Revision: 2.4 $
+#	$Author: roman $
+#	$Date: 1998/12/09 14:39:31 $
 
 # This is a very simple whois client module
 
@@ -62,6 +62,10 @@ sub initwhoisqry {
     else {
        $address=(gethostbyname($host))[4];
     }
+
+    unless ($address) {
+       return "Connect to host: $host port: $port failed: host unknown";
+    }
     
     # find valid port and protocol number for whois service
     
@@ -91,7 +95,7 @@ sub initwhoisqry {
     }
     else {
     
-       return ("Connect to host: $host port: $port failed");
+       return "Connect to host: $host port: $port failed: $!";
 
     }
     
